==> blesta-5.10.2.zip: blesta/components/modules/enom/language/zh_cn/enom.php <==
<?php
/**
 * Enom
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Enom.whois.AuxBillingPostalCode'] = '邮政编码';
$lang['Enom.domain.ASIAIdentNumber'] = '身份编号';
$lang['Enom.domain.ASIAIdentForm.passport'] = '护照/公民身份证';
$lang['Enom.domain.ASIAIdentForm.politicalPartyRegistry'] = '政党登记';
$lang['Enom.domain.ASIAIdentForm.societyRegistry'] = '社团登记处';
$lang['Enom.domain.ASIAIdentForm.legislation'] = '宪章';
$lang['Enom.domain.ASIAIdentForm.certificate'] = '公司注册证书';
$lang['Enom.domain.ASIAIdentForm'] = '身份形式';
$lang['Enom.domain.ASIALegalEntityType.naturalPerson'] = '自然人';
$lang['Enom.domain.ASIALegalEntityType.institution'] = '机构';
$lang['Enom.domain.ASIALegalEntityType.society'] = '信托、遗产、协会或社团';
$lang['Enom.domain.ASIALegalEntityType.politicalParty'] = '政党或工会';
$lang['Enom.domain.ASIALegalEntityType.government'] = '政府机构';
$lang['Enom.domain.ASIALegalEntityType.partnership'] = '合作伙伴或集体';
$lang['Enom.domain.ASIALegalEntityType.cooperative'] = '合作社';
$lang['Enom.domain.ASIALegalEntityType.corporation'] = '公司或企业';
$lang['Enom.domain.ASIALegalEntityType'] = '法律类型';
$lang['Enom.domain.UKRegisteredfor'] = '注册人姓名';
$lang['Enom.domain.UKCompanyID'] = '公司 ID 编号';
$lang['Enom.domain.UKLegalType.fother'] = '其他外国组织';
$lang['Enom.domain.UKLegalType.stat'] = '英国法定机构 FIND';
$lang['Enom.domain.UKLegalType.fcorp'] = '外国组织';
$lang['Enom.domain.UKLegalType.crc'] = '英国皇家特许公司';
$lang['Enom.domain.UKLegalType.other'] = '英国实体（其他）';
$lang['Enom.domain.UKLegalType.gov'] = '英国政府机构';
$lang['Enom.domain.UKLegalType.rchar'] = '英国注册慈善机构';
$lang['Enom.domain.UKLegalType.sch'] = '英国学校';
$lang['Enom.domain.UKLegalType.stra'] = '英国个体经营者';
$lang['Enom.domain.UKLegalType.ip'] = '英国工业/供应商注册公司';
$lang['Enom.domain.UKLegalType.llp'] = '英国有限责任合伙企业';
$lang['Enom.domain.UKLegalType.ptnr'] = '英国合作伙伴';
$lang['Enom.domain.UKLegalType.plc'] = '英国公共有限公司';
$lang['Enom.domain.UKLegalType.ltd'] = '英国有限公司';
$lang['Enom.domain.UKLegalType.find'] = '非联合王国个人';
$lang['Enom.domain.UKLegalType.ind'] = '英国个人';
$lang['Enom.domain.UKLegalType'] = '法律类型';
$lang['Enom.domain.CIRALanguage.fr'] = '法语';
$lang['Enom.domain.CIRALanguage.en'] = '英语';
$lang['Enom.domain.CIRALanguage'] = '首选交流语言';
$lang['Enom.domain.CIRAWhoisDisplay.private'] = '保持私密';
$lang['Enom.domain.CIRAWhoisDisplay.full'] = '公开';
$lang['Enom.domain.CIRAWhoisDisplay'] = 'Whois';
$lang['Enom.domain.RegistrantPurpose.maj'] = '女王';
$lang['Enom.domain.RegistrantPurpose.omk'] = '官方标志';
$lang['Enom.domain.RegistrantPurpose.lgr'] = '法律代表';
$lang['Enom.domain.RegistrantPurpose.inb'] = '印度乐队';
$lang['Enom.domain.RegistrantPurpose.abo'] = '原住民';
$lang['Enom.domain.RegistrantPurpose.trs'] = '信任';
$lang['Enom.domain.RegistrantPurpose.lam'] = '图书馆、档案馆和博物馆';
$lang['Enom.domain.RegistrantPurpose.plt'] = '政党';
$lang['Enom.domain.RegistrantPurpose.trd'] = '工会';
$lang['Enom.domain.RegistrantPurpose.tdm'] = '商标';
$lang['Enom.domain.RegistrantPurpose.prt'] = '合作伙伴';
$lang['Enom.domain.RegistrantPurpose.hop'] = '医院';
$lang['Enom.domain.RegistrantPurpose.ass'] = '非法人协会';
$lang['Enom.domain.RegistrantPurpose.edu'] = '教育';
$lang['Enom.domain.RegistrantPurpose.gov'] = '政府实体';
$lang['Enom.domain.RegistrantPurpose.res'] = '加拿大居民';
$lang['Enom.domain.RegistrantPurpose.cct'] = '加拿大公民';
$lang['Enom.domain.RegistrantPurpose.cco'] = '公司';
$lang['Enom.domain.CIRALegalType'] = '法律类型';
$lang['Enom.domain.EUAgreeDeletePolicy.yes'] = '本人同意并承认以下关于此域名的特殊续期和到期条款，包括注册协议中规定的条款。本人明白，除非本人已将此域名设置为自动续期，否则必须在到期日或到期当月的 20 日（以较早者为准）之前对该域名进行明确续期。(例如：如果域名于 2008 年 9 月 4 日到期，则必须在 2008 年 9 月 4 日之前收到手动续期申请。如果名称于 2008 年 9 月 27 日到期，则必须在 2008 年 9 月 20 日之前收到续期申请）。如果未手动续订或之前未将名称设置为自动更新，Enom 将发出删除请求。在发出删除请求后，我的账户中的名称仍可正常使用直至到期，但不能再续费，也不能对名称进行任何修改。以上条款如有更改，恕不另行通知。';
$lang['Enom.domain.EUAgreeDeletePolicy'] = '删除规则';
$lang['Enom.domain.EUAgreeWhoisPolicy.yes'] = '本人特此同意，注册局有权将本申请中包含的数据传输给第三方：(i)如果公共机构在执行其合法任务时命令这样做；以及(ii)根据 ADR 提供者的要求，如 www.eurid.eu 上公布的条款和条件第 16 条所述；以及(iii)根据 www.eurid.eu 上公布的.eu 域名 WHOIS 政策第 2 条（WHOIS 查询设施）的规定。';
$lang['Enom.domain.EUAgreeWhoisPolicy'] = 'Whois 政策';
$lang['Enom.domain.RegistrantPurpose.p5'] = '政府';
$lang['Enom.domain.RegistrantPurpose.p4'] = '教育';
$lang['Enom.domain.RegistrantPurpose.p3'] = '个人';
$lang['Enom.domain.RegistrantPurpose.p2'] = '非营利';
$lang['Enom.domain.RegistrantPurpose.p1'] = '商业';
$lang['Enom.domain.RegistrantPurpose'] = '目的';
$lang['Enom.domain.RegistrantNexus.c32'] = '在美国设有办事处的外国组织';
$lang['Enom.domain.RegistrantNexus.c31'] = '外国组织';
$lang['Enom.domain.RegistrantNexus.c21'] = '美国实体或组织';
$lang['Enom.domain.RegistrantNexus.c12'] = '美国永久居民';
$lang['Enom.domain.RegistrantNexus.c11'] = '美国公民';
$lang['Enom.domain.RegistrantNexus'] = '注册人类型';
$lang['Enom.whois.AuxBillingEmailAddress'] = '电子邮件';
$lang['Enom.whois.AuxBillingPhone'] = '电话';
$lang['Enom.whois.AuxBillingCountry'] = '国家';
$lang['Enom.whois.AuxBillingStateProvince'] = '州/省';
$lang['Enom.whois.AuxBillingCity'] = '城市';
$lang['Enom.whois.AuxBillingAddress2'] = '地址 2';
$lang['Enom.whois.AuxBillingAddress1'] = '地址 1';
$lang['Enom.whois.AuxBillingLastName'] = '姓氏';
$lang['Enom.whois.AuxBillingFirstName'] = '姓名';
$lang['Enom.whois.AdminEmailAddress'] = '电子邮件';
$lang['Enom.whois.AdminPhone'] = '电话';
$lang['Enom.whois.AdminCountry'] = '国家';
$lang['Enom.whois.AdminPostalCode'] = '邮政编码';
$lang['Enom.whois.AdminStateProvince'] = '州/省';
$lang['Enom.whois.AdminCity'] = '城市';
$lang['Enom.whois.AdminAddress2'] = '地址 2';
$lang['Enom.whois.AdminAddress1'] = '地址 1';
$lang['Enom.whois.AdminLastName'] = '姓氏';
$lang['Enom.whois.AdminFirstName'] = '姓名';
$lang['Enom.whois.TechEmailAddress'] = '电子邮件';
$lang['Enom.whois.TechPhone'] = '电话';
$lang['Enom.whois.TechCountry'] = '国家';
$lang['Enom.whois.TechPostalCode'] = '邮政编码';
$lang['Enom.whois.TechStateProvince'] = '州/省';
$lang['Enom.whois.TechCity'] = '城市';
$lang['Enom.whois.TechAddress2'] = '地址 2';
$lang['Enom.whois.TechAddress1'] = '地址 1';
$lang['Enom.whois.TechLastName'] = '姓氏';
$lang['Enom.whois.TechFirstName'] = '姓名';
$lang['Enom.whois.RegistrantEmailAddress'] = '电子邮件';
$lang['Enom.whois.RegistrantPhone'] = '电话';
$lang['Enom.whois.RegistrantCountry'] = '国家';
$lang['Enom.whois.RegistrantPostalCode'] = '邮政编码';
$lang['Enom.whois.RegistrantStateProvince'] = '州/省';
$lang['Enom.whois.RegistrantCity'] = '城市';
$lang['Enom.whois.RegistrantAddress2'] = '地址 2';
$lang['Enom.whois.RegistrantAddress1'] = '地址 1';
$lang['Enom.whois.RegistrantLastName'] = '姓氏';
$lang['Enom.whois.RegistrantFirstName'] = '姓名';
$lang['Enom.module_row'] = '账户';
$lang['Enom.description'] = 'Enom, Inc. 是一家域名注册商和网络托管公司，还销售与域名密切相关的其他产品，如 SSL 证书、电子邮件服务和网站建设软件。';
$lang['Enom.domain.NumYears'] = '年数';
$lang['Enom.domain.domain'] = '域名';
$lang['Enom.transfer.transfer_key'] = 'EPP 代码';
$lang['Enom.transfer.domain'] = '域名';
$lang['Enom.!error.key.valid_connection'] = '用户和密码组合似乎无效，或者您的 Enom 账户可能未配置为允许 API 访问。';
$lang['Enom.!error.key.valid'] = '请输入密码。';
$lang['Enom.!error.user.valid'] = '请输入用户名。';
$lang['Enom.tab_settings.field_submit'] = '更新设置';
$lang['Enom.tab_settings.field_request_epp'] = '申请 EPP 密码/转移密钥';
$lang['Enom.tab_settings.field_registrar_lock_no'] = '解除注册商锁定，以便转移域名。';
$lang['Enom.tab_settings.field_registrar_lock_yes'] = '设置注册商锁定。建议用于防止未经授权的转让。';
$lang['Enom.tab_settings.field_registrar_lock'] = '注册锁';
$lang['Enom.tab_settings.title'] = '设置';
$lang['Enom.tab_nameservers.field_submit'] = '更新名称服务器';
$lang['Enom.tab_nameserver.field_ns'] = '名称服务器 %1$s';
$lang['Enom.tab_nameservers.title'] = '名称服务器';
$lang['Enom.tab_whois.field_submit'] = '更新 Whois';
$lang['Enom.tab_whois.section_AuxBilling'] = '账单';
$lang['Enom.tab_whois.section_Tech'] = '技术';
$lang['Enom.tab_whois.section_Admin'] = '行政管理';
$lang['Enom.tab_whois.section_Registrant'] = '注册人';
$lang['Enom.tab_whois.title'] = 'Whois';
$lang['Enom.package_fields.ns5'] = '名称服务器 5';
$lang['Enom.package_fields.ns4'] = '名称服务器 4';
$lang['Enom.package_fields.ns3'] = '名称服务器 3';
$lang['Enom.package_fields.ns2'] = '名称服务器 2';
$lang['Enom.package_fields.ns1'] = '名称服务器 1';
$lang['Enom.package_fields.tld_options'] = '顶级域名';
$lang['Enom.package_fields.type_ssl'] = 'SSL 证书';
$lang['Enom.package_fields.type_domain'] = '域名注册';
$lang['Enom.package_fields.type'] = '类型';
$lang['Enom.edit_row.add_btn'] = '更新账户';
$lang['Enom.edit_row.basic_title'] = '基本设置';
$lang['Enom.edit_row.box_title'] = '编辑 Enom 帐户';
$lang['Enom.add_row.add_btn'] = '添加账户';
$lang['Enom.add_row.basic_title'] = '基本设置';
$lang['Enom.add_row.box_title'] = '添加 Enom 帐户';
$lang['Enom.row_meta.sandbox_false'] = '没有';
$lang['Enom.row_meta.sandbox_true'] = '是';
$lang['Enom.row_meta.sandbox'] = '沙盒';
$lang['Enom.row_meta.key'] = '密码';
$lang['Enom.row_meta.user'] = '用户';
$lang['Enom.manage.module_rows_no_results'] = '没有账户。';
$lang['Enom.manage.module_rows.confirm_delete'] = '您确定要删除此帐户吗？';
$lang['Enom.manage.module_rows.delete'] = '删除';
$lang['Enom.manage.module_rows.edit'] = '编辑';
$lang['Enom.manage.module_rows_heading.options'] = '选项';
$lang['Enom.manage.module_rows_heading.sandbox'] = '沙盒';
$lang['Enom.manage.module_rows_heading.key'] = 'API 密钥';
$lang['Enom.manage.module_rows_heading.user'] = '用户';
$lang['Enom.manage.module_rows_title'] = '账户';
$lang['Enom.add_module_row'] = '添加账户';
$lang['Enom.module_row_plural'] = '账户';
$lang['Enom.nameserver.ns5'] = 'Name Server 5';
$lang['Enom.nameserver.ns4'] = 'Name Server 4';
$lang['Enom.nameserver.ns3'] = 'Name Server 3';
$lang['Enom.nameserver.ns2'] = 'Name Server 2';
$lang['Enom.name'] = 'Enom';
$lang['Enom.nameserver.ns1'] = 'Name Server 1';

==> blesta-5.11.4.zip: blesta/components/modules/enom/language/zh_cn/enom.php <==
<?php
/**
 * Enom
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Enom.whois.AuxBillingPostalCode'] = '邮政编码';
$lang['Enom.domain.ASIAIdentNumber'] = '身份编号';
$lang['Enom.domain.ASIAIdentForm.passport'] = '护照/公民身份证';
$lang['Enom.domain.ASIAIdentForm.politicalPartyRegistry'] = '政党登记';
$lang['Enom.domain.ASIAIdentForm.societyRegistry'] = '社团登记处';
$lang['Enom.domain.ASIAIdentForm.legislation'] = '宪章';
$lang['Enom.domain.ASIAIdentForm.certificate'] = '公司注册证书';
$lang['Enom.domain.ASIAIdentForm'] = '身份形式';
$lang['Enom.domain.ASIALegalEntityType.naturalPerson'] = '自然人';
$lang['Enom.domain.ASIALegalEntityType.institution'] = '机构';
$lang['Enom.domain.ASIALegalEntityType.society'] = '信托、遗产、协会或社团';
$lang['Enom.domain.ASIALegalEntityType.politicalParty'] = '政党或工会';
$lang['Enom.domain.ASIALegalEntityType.government'] = '政府机构';
$lang['Enom.domain.ASIALegalEntityType.partnership'] = '合作伙伴或集体';
$lang['Enom.domain.ASIALegalEntityType.cooperative'] = '合作社';
$lang['Enom.domain.ASIALegalEntityType.corporation'] = '公司或企业';
$lang['Enom.domain.ASIALegalEntityType'] = '法律类型';
$lang['Enom.domain.UKRegisteredfor'] = '注册人姓名';
$lang['Enom.domain.UKCompanyID'] = '公司 ID 编号';
$lang['Enom.domain.UKLegalType.fother'] = '其他外国组织';
$lang['Enom.domain.UKLegalType.stat'] = '英国法定机构 FIND';
$lang['Enom.domain.UKLegalType.fcorp'] = '外国组织';
$lang['Enom.domain.UKLegalType.crc'] = '英国皇家特许公司';
$lang['Enom.domain.UKLegalType.other'] = '英国实体（其他）';
$lang['Enom.domain.UKLegalType.gov'] = '英国政府机构';
$lang['Enom.domain.UKLegalType.rchar'] = '英国注册慈善机构';
$lang['Enom.domain.UKLegalType.sch'] = '英国学校';
$lang['Enom.domain.UKLegalType.stra'] = '英国个体经营者';
$lang['Enom.domain.UKLegalType.ip'] = '英国工业/供应商注册公司';
$lang['Enom.domain.UKLegalType.llp'] = '英国有限责任合伙企业';
$lang['Enom.domain.UKLegalType.ptnr'] = '英国合作伙伴';
$lang['Enom.domain.UKLegalType.plc'] = '英国公共有限公司';
$lang['Enom.domain.UKLegalType.ltd'] = '英国有限公司';
$lang['Enom.domain.UKLegalType.find'] = '非联合王国个人';
$lang['Enom.domain.UKLegalType.ind'] = '英国个人';
$lang['Enom.domain.UKLegalType'] = '法律类型';
$lang['Enom.domain.CIRALanguage.fr'] = '法语';
$lang['Enom.domain.CIRALanguage.en'] = '英语';
$lang['Enom.domain.CIRALanguage'] = '首选交流语言';
$lang['Enom.domain.CIRAWhoisDisplay.private'] = '保持私密';
$lang['Enom.domain.CIRAWhoisDisplay.full'] = '公开';
$lang['Enom.domain.CIRAWhoisDisplay'] = 'Whois';
$lang['Enom.domain.RegistrantPurpose.maj'] = '女王';
$lang['Enom.domain.RegistrantPurpose.omk'] = '官方标志';
$lang['Enom.domain.RegistrantPurpose.lgr'] = '法律代表';
$lang['Enom.domain.RegistrantPurpose.inb'] = '印度乐队';
$lang['Enom.domain.RegistrantPurpose.abo'] = '原住民';
$lang['Enom.domain.RegistrantPurpose.trs'] = '信任';
$lang['Enom.domain.RegistrantPurpose.lam'] = '图书馆、档案馆和博物馆';
$lang['Enom.domain.RegistrantPurpose.plt'] = '政党';
$lang['Enom.domain.RegistrantPurpose.trd'] = '工会';
$lang['Enom.domain.RegistrantPurpose.tdm'] = '商标';
$lang['Enom.domain.RegistrantPurpose.prt'] = '合作伙伴';
$lang['Enom.domain.RegistrantPurpose.hop'] = '医院';
$lang['Enom.domain.RegistrantPurpose.ass'] = '非法人协会';
$lang['Enom.domain.RegistrantPurpose.edu'] = '教育';
$lang['Enom.domain.RegistrantPurpose.gov'] = '政府实体';
$lang['Enom.domain.RegistrantPurpose.res'] = '加拿大居民';
$lang['Enom.domain.RegistrantPurpose.cct'] = '加拿大公民';
$lang['Enom.domain.RegistrantPurpose.cco'] = '公司';
$lang['Enom.domain.CIRALegalType'] = '法律类型';
$lang['Enom.domain.EUAgreeDeletePolicy.yes'] = '本人同意并承认以下关于此域名的特殊续期和到期条款，包括注册协议中规定的条款。本人明白，除非本人已将此域名设置为自动续期，否则必须在到期日或到期当月的 20 日（以较早者为准）之前对该域名进行明确续期。(例如：如果域名于 2008 年 9 月 4 日到期，则必须在 2008 年 9 月 4 日之前收到手动续期申请。如果名称于 2008 年 9 月 27 日到期，则必须在 2008 年 9 月 20 日之前收到续期申请）。如果未手动续订或之前未将名称设置为自动更新，Enom 将发出删除请求。在发出删除请求后，我的账户中的名称仍可正常使用直至到期，但不能再续费，也不能对名称进行任何修改。以上条款如有更改，恕不另行通知。';
$lang['Enom.domain.EUAgreeDeletePolicy'] = '删除规则';
$lang['Enom.domain.EUAgreeWhoisPolicy.yes'] = '本人特此同意，注册局有权将本申请中包含的数据传输给第三方：(i)如果公共机构在执行其合法任务时命令这样做；以及(ii)根据 ADR 提供者的要求，如 www.eurid.eu 上公布的条款和条件第 16 条所述；以及(iii)根据 www.eurid.eu 上公布的.eu 域名 WHOIS 政策第 2 条（WHOIS 查询设施）的规定。';
$lang['Enom.domain.EUAgreeWhoisPolicy'] = 'Whois 政策';
$lang['Enom.domain.RegistrantPurpose.p5'] = '政府';
$lang['Enom.domain.RegistrantPurpose.p4'] = '教育';
$lang['Enom.domain.RegistrantPurpose.p3'] = '个人';
$lang['Enom.domain.RegistrantPurpose.p2'] = '非营利';
$lang['Enom.domain.RegistrantPurpose.p1'] = '商业';
$lang['Enom.domain.RegistrantPurpose'] = '目的';
$lang['Enom.domain.RegistrantNexus.c32'] = '在美国设有办事处的外国组织';
$lang['Enom.domain.RegistrantNexus.c31'] = '外国组织';
$lang['Enom.domain.RegistrantNexus.c21'] = '美国实体或组织';
$lang['Enom.domain.RegistrantNexus.c12'] = '美国永久居民';
$lang['Enom.domain.RegistrantNexus.c11'] = '美国公民';
$lang['Enom.domain.RegistrantNexus'] = '注册人类型';
$lang['Enom.whois.AuxBillingEmailAddress'] = '电子邮件';
$lang['Enom.whois.AuxBillingPhone'] = '电话';
$lang['Enom.whois.AuxBillingCountry'] = '国家';
$lang['Enom.whois.AuxBillingStateProvince'] = '州/省';
$lang['Enom.whois.AuxBillingCity'] = '城市';
$lang['Enom.whois.AuxBillingAddress2'] = '地址 2';
$lang['Enom.whois.AuxBillingAddress1'] = '地址 1';
$lang['Enom.whois.AuxBillingLastName'] = '姓氏';
$lang['Enom.whois.AuxBillingFirstName'] = '姓名';
$lang['Enom.whois.AdminEmailAddress'] = '电子邮件';
$lang['Enom.whois.AdminPhone'] = '电话';
$lang['Enom.whois.AdminCountry'] = '国家';
$lang['Enom.whois.AdminPostalCode'] = '邮政编码';
$lang['Enom.whois.AdminStateProvince'] = '州/省';
$lang['Enom.whois.AdminCity'] = '城市';
$lang['Enom.whois.AdminAddress2'] = '地址 2';
$lang['Enom.whois.AdminAddress1'] = '地址 1';
$lang['Enom.whois.AdminLastName'] = '姓氏';
$lang['Enom.whois.AdminFirstName'] = '姓名';
$lang['Enom.whois.TechEmailAddress'] = '电子邮件';
$lang['Enom.whois.TechPhone'] = '电话';
$lang['Enom.whois.TechCountry'] = '国家';
$lang['Enom.whois.TechPostalCode'] = '邮政编码';
$lang['Enom.whois.TechStateProvince'] = '州/省';
$lang['Enom.whois.TechCity'] = '城市';
$lang['Enom.whois.TechAddress2'] = '地址 2';
$lang['Enom.whois.TechAddress1'] = '地址 1';
$lang['Enom.whois.TechLastName'] = '姓氏';
$lang['Enom.whois.TechFirstName'] = '姓名';
$lang['Enom.whois.RegistrantEmailAddress'] = '电子邮件';
$lang['Enom.whois.RegistrantPhone'] = '电话';
$lang['Enom.whois.RegistrantCountry'] = '国家';
$lang['Enom.whois.RegistrantPostalCode'] = '邮政编码';
$lang['Enom.whois.RegistrantStateProvince'] = '州/省';
$lang['Enom.whois.RegistrantCity'] = '城市';
$lang['Enom.whois.RegistrantAddress2'] = '地址 2';
$lang['Enom.whois.RegistrantAddress1'] = '地址 1';
$lang['Enom.whois.RegistrantLastName'] = '姓氏';
$lang['Enom.whois.RegistrantFirstName'] = '姓名';
$lang['Enom.module_row'] = '账户';
$lang['Enom.description'] = 'Enom, Inc. 是一家域名注册商和网络托管公司，还销售与域名密切相关的其他产品，如 SSL 证书、电子邮件服务和网站建设软件。';
$lang['Enom.domain.NumYears'] = '年数';
$lang['Enom.domain.domain'] = '域名';
$lang['Enom.transfer.transfer_key'] = 'EPP 代码';
$lang['Enom.transfer.domain'] = '域名';
$lang['Enom.!error.key.valid_connection'] = '用户和密码（或 api 密钥）组合似乎无效，或者您的 Enom 账户可能未配置为允许 API 访问。';
$lang['Enom.!error.key.valid'] = '请输入密码或 api 密钥。';
$lang['Enom.!error.user.valid'] = '请输入用户名。';
$lang['Enom.tab_settings.field_submit'] = '更新设置';
$lang['Enom.tab_settings.field_request_epp'] = '申请 EPP 密码/转移密钥';
$lang['Enom.tab_settings.field_registrar_lock_no'] = '解除注册商锁定，以便转移域名。';
$lang['Enom.tab_settings.field_registrar_lock_yes'] = '设置注册商锁定。建议用于防止未经授权的转让。';
$lang['Enom.tab_settings.field_registrar_lock'] = '注册锁';
$lang['Enom.tab_settings.title'] = '设置';
$lang['Enom.tab_nameservers.field_submit'] = '更新名称服务器';
$lang['Enom.tab_nameserver.field_ns'] = '名称服务器 %1$s';
$lang['Enom.tab_nameservers.title'] = '名称服务器';
$lang['Enom.tab_whois.field_submit'] = '更新 Whois';
$lang['Enom.tab_whois.section_AuxBilling'] = '账单';
$lang['Enom.tab_whois.section_Tech'] = '技术';
$lang['Enom.tab_whois.section_Admin'] = '行政管理';
$lang['Enom.tab_whois.section_Registrant'] = '注册人';
$lang['Enom.tab_whois.title'] = 'Whois';
$lang['Enom.package_fields.ns5'] = '名称服务器 5';
$lang['Enom.package_fields.ns4'] = '名称服务器 4';
$lang['Enom.package_fields.ns3'] = '名称服务器 3';
$lang['Enom.package_fields.ns2'] = '名称服务器 2';
$lang['Enom.package_fields.ns1'] = '名称服务器 1';
$lang['Enom.package_fields.tld_options'] = '顶级域名';
$lang['Enom.package_fields.type_ssl'] = 'SSL 证书';
$lang['Enom.package_fields.type_domain'] = '域名注册';
$lang['Enom.package_fields.type'] = '类型';
$lang['Enom.edit_row.add_btn'] = '更新账户';
$lang['Enom.edit_row.basic_title'] = '基本设置';
$lang['Enom.edit_row.box_title'] = '编辑 Enom 帐户';
$lang['Enom.add_row.add_btn'] = '添加账户';
$lang['Enom.add_row.basic_title'] = '基本设置';
$lang['Enom.add_row.box_title'] = '添加 Enom 帐户';
$lang['Enom.row_meta.sandbox_false'] = '没有';
$lang['Enom.row_meta.sandbox_true'] = '是';
$lang['Enom.row_meta.sandbox'] = '沙盒';
$lang['Enom.row_meta.key'] = 'API 密钥或密码';
$lang['Enom.row_meta.user'] = '用户';
$lang['Enom.manage.module_rows_no_results'] = '没有账户。';
$lang['Enom.manage.module_rows.confirm_delete'] = '您确定要删除此帐户吗？';
$lang['Enom.manage.module_rows.delete'] = '删除';
$lang['Enom.manage.module_rows.edit'] = '编辑';
$lang['Enom.manage.module_rows_heading.options'] = '选项';
$lang['Enom.manage.module_rows_heading.sandbox'] = '沙盒';
$lang['Enom.manage.module_rows_heading.key'] = 'API 密钥或密码';
$lang['Enom.manage.module_rows_heading.user'] = '用户';
$lang['Enom.manage.module_rows_title'] = '账户';
$lang['Enom.add_module_row'] = '添加账户';
$lang['Enom.module_row_plural'] = '账户';
$lang['Enom.nameserver.ns5'] = 'Name Server 5';
$lang['Enom.nameserver.ns4'] = 'Name Server 4';
$lang['Enom.nameserver.ns3'] = 'Name Server 3';
$lang['Enom.nameserver.ns2'] = 'Name Server 2';
$lang['Enom.name'] = 'Enom';
$lang['Enom.nameserver.ns1'] = 'Name Server 1';
